// -*- C++ -*-
#include "Rivet/Analysis.hh"
#include "Rivet/Projections/ChargedFinalState.hh"

namespace Rivet {


  /// @brief OPAL LEP1 charged multiplicity, code basically a copy of the ALEPH one
  /// @author Peter Richardson
  class OPAL_1992_I321190 : public Analysis {
  public:

    /// Constructor
    RIVET_DEFAULT_ANALYSIS_CTOR(OPAL_1992_I321190);


    /// @name Analysis methods
    /// @{

    /// Book histograms and initialise projections before the run
    void init() {
      const ChargedFinalState cfs;
      declare(cfs, "CFS");

      book(_histChTot, 1, 1, 1);
      book(_histAver , 5, 1, 1);
    }


    /// Perform the per-event analysis
    void analyze(const Event& event) {
      const FinalState& cfs = apply<FinalState>(event, "CFS");
      MSG_DEBUG("Total charged multiplicity = " << cfs.size());
      _histChTot->fill(cfs.size());
      _histAver->fill(Ecm, cfs.size());
    }


    /// Normalise histograms etc., after the run
    void finalize() {
      scale(_histChTot, 100.0/sumOfWeights()); // %age (100)
    }

    /// @}


  private:

    /// @name Histograms
    /// @{
    BinnedHistoPtr<int> _histChTot;
    BinnedProfilePtr<string> _histAver;
    const string Ecm = "91.2";
    /// @}

  };


  RIVET_DECLARE_PLUGIN(OPAL_1992_I321190);


}
